@@ -1,14 +1,35 @@
 context("cts")
 
+chk_cts <- function(){
+  qurl <- 'http://cts.fiehnlab.ucdavis.edu/service/compound/XEFQLINVKFYRCS-UHFFFAOYSA-N'
+  Sys.sleep(0.2)
+  cont <- try(getURL(qurl, .encoding = 'UTF-8', .opts = list(timeout = 3)),
+              silent = TRUE)
+  if (inherits(cont, 'try-error'))
+    skip("Server is down!")
+}
+
+chk_cir <- function(){
+  qurl <- 'http://cactus.nci.nih.gov/chemical/structure/Triclosan/cas/xml'
+  Sys.sleep(0.2)
+  cont <- try(getURL(qurl, .encoding = 'UTF-8', .opts = list(timeout = 3)),
+              silent = TRUE)
+  if (inherits(cont, 'try-error'))
+    skip("Server is down!")
+}
+
+
 test_that("cts_compinfo()", {
+  chk_cts()
   expect_error(cts_compinfo(c('xxxxx', 'aaaaaaa')))
   expect_equal(cts_compinfo('xxxxx', verbose = FALSE), NA)
   expect_equal(length(cts_compinfo("XEFQLINVKFYRCS-UHFFFAOYSA-N", verbose = FALSE)), 7)
-  expect_equal(round(cts_compinfo("XEFQLINVKFYRCS-UHFFFAOYSA-N", verbose = FALSE)[[3]], 4), 289.5418)
+  expect_equal(round(cts_compinfo("XEFQLINVKFYRCS-UHFFFAOYSA-N", verbose = FALSE)[[3]], 3), 289.542)
 })
 
 
 test_that("cts_convert()", {
+  chk_cts()
   expect_error(cts_convert(c('xxxxx', 'aaaaaaa'), 'Chemical Name', 'CAS'))
   expect_error(cts_convert('Triclosan', c('Chemical Name', 'CAS'), 'CAS'))
   expect_error(cts_convert('Triclosan', 'CAS'))
@@ -20,8 +41,10 @@ test_that("cts_convert()", {
 })
 
 test_that("cts_compinfo(cir_query())", {
-  expect_equal(round(cts_compinfo(
-    gsub('InChIKey=', '', cir_query('Triclosan', representation = 'stdinchikey', verbose = FALSE)),
-    verbose = FALSE)[[3]], 4), 289.5418)
+  chk_cts()
+  chk_cir()
+  inchikey <- cir_query('Triclosan', representation = 'stdinchikey', verbose = FALSE)
+  inchikey <- gsub('InChIKey=', '', inchikey)
+  expect_equal(round(cts_compinfo(inchikey, verbose = FALSE)[[3]], 3), 289.542)
 
 })
\ No newline at end of file
